==> jc-1.4.0.tar.gz: java/rmi/server/UID.h <==
// public final class java.rmi.server.UID

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3574ef25fd505caa java_rmi_server_UID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_UID_H_
#define _JC_java_rmi_server_UID_H_

// Forward structure declarations
struct _jc_java_io_DataInput$object;
struct _jc_java_io_DataOutput$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_server_UID$sub_refs	_jc_java_rmi_server_UID$sub_refs;
typedef struct _jc_java_rmi_server_UID$sub_nonrefs	_jc_java_rmi_server_UID$sub_nonrefs;
typedef struct _jc_java_rmi_server_UID$refs	_jc_java_rmi_server_UID$refs;
typedef struct _jc_java_rmi_server_UID$nonrefs	_jc_java_rmi_server_UID$nonrefs;
typedef struct _jc_java_rmi_server_UID$object	_jc_java_rmi_server_UID$object;

typedef struct _jc_java_rmi_server_UID$fields_struct	_jc_java_rmi_server_UID$fields_struct;
typedef const struct _jc_java_rmi_server_UID$vmethods	_jc_java_rmi_server_UID$vmethods;
typedef const struct _jc_java_rmi_server_UID$vtable	_jc_java_rmi_server_UID$vtable;
typedef const struct _jc_java_rmi_server_UID$vtype	_jc_java_rmi_server_UID$vtype;

// Class fields structure
struct _jc_java_rmi_server_UID$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24UID;
	struct _jc_java_lang_Object$object	*lock;
	jlong	baseTime;
	jlong	serialVersionUID;
	jint	uniqueNr;
	jshort	nextCount;
};
extern _jc_java_rmi_server_UID$fields_struct _jc_java_rmi_server_UID$class_fields;

// Constructors
extern void _jc_java_rmi_server_UID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_UID$object *);
extern void _jc_java_rmi_server_UID$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_java_rmi_server_UID$object *, jshort);

// Virtual methods
extern jboolean _jc_java_rmi_server_UID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_rmi_server_UID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_UID$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_UID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_UID$object *);
extern void _jc_java_rmi_server_UID$method$write$dcca4977396db63b(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_UID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_UID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_UID$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_UID$method_info$write$dcca4977396db63b;

// Static methods
extern void _jc_java_rmi_server_UID$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_UID$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern struct _jc_java_rmi_server_UID$object *_jc_java_rmi_server_UID$method$read$3813ee958ede2fb4(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_java_rmi_server_UID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_UID$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_UID$object *);
	void	(*write$dcca4977396db63b)(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_rmi_server_UID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_UID$vmethods	java_rmi_server_UID;
};

// Vtype
struct _jc_java_rmi_server_UID$vtype {
	_jc_type			type;
	_jc_java_rmi_server_UID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_UID$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_UID$refs {
    _jc_java_rmi_server_UID$sub_refs	java_rmi_server_UID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_UID$sub_nonrefs {
	jint	unique;
	jlong	time;
	jshort	count;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_UID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_UID$sub_nonrefs	java_rmi_server_UID;
};

// Object instance structure
struct _jc_java_rmi_server_UID$object {
	_jc_java_rmi_server_UID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_UID$vtype	*vtype;
	_jc_java_rmi_server_UID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_UID$vtype _jc_java_rmi_server_UID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_UID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_UID$class_object;

#endif	/* _JC_java_rmi_server_UID_H_ */

==> jc-1.4.6.tar.gz: java/rmi/server/UID.h <==
// public final class java.rmi.server.UID

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3574ef25fd505caa java_rmi_server_UID

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_rmi_server_UID_H_
#define _JC_java_rmi_server_UID_H_

// Forward structure declarations
struct _jc_java_io_DataInput$object;
struct _jc_java_io_DataOutput$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_rmi_server_UID$object;

// Typedefs
typedef struct _jc_java_rmi_server_UID$sub_refs	_jc_java_rmi_server_UID$sub_refs;
typedef struct _jc_java_rmi_server_UID$sub_nonrefs	_jc_java_rmi_server_UID$sub_nonrefs;
typedef struct _jc_java_rmi_server_UID$refs	_jc_java_rmi_server_UID$refs;
typedef struct _jc_java_rmi_server_UID$nonrefs	_jc_java_rmi_server_UID$nonrefs;
typedef struct _jc_java_rmi_server_UID$object	_jc_java_rmi_server_UID$object;

typedef struct _jc_java_rmi_server_UID$fields_struct	_jc_java_rmi_server_UID$fields_struct;
typedef const struct _jc_java_rmi_server_UID$vmethods	_jc_java_rmi_server_UID$vmethods;
typedef const struct _jc_java_rmi_server_UID$vtable	_jc_java_rmi_server_UID$vtable;
typedef const struct _jc_java_rmi_server_UID$vtype	_jc_java_rmi_server_UID$vtype;

// Class fields structure
struct _jc_java_rmi_server_UID$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24rmi__24server__24UID;
	struct _jc_java_lang_Object$object	*lock;
	jlong	baseTime;
	jlong	serialVersionUID;
	jint	uniqueNr;
	jshort	nextCount;
};
extern _jc_java_rmi_server_UID$fields_struct _jc_java_rmi_server_UID$class_fields;

// Constructors
extern void _jc_java_rmi_server_UID$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_server_UID$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UID$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_java_rmi_server_UID$object *, jshort) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_rmi_server_UID$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_rmi_server_UID$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_rmi_server_UID$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_server_UID$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_rmi_server_UID$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_server_UID$method$write$dcca4977396db63b(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_server_UID$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_rmi_server_UID$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_rmi_server_UID$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_java_rmi_server_UID$method_info$write$dcca4977396db63b;

// Static methods
extern void _jc_java_rmi_server_UID$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_rmi_server_UID$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_rmi_server_UID$object *_jc_java_rmi_server_UID$method$read$3813ee958ede2fb4(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_rmi_server_UID$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_rmi_server_UID$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_rmi_server_UID$object *) _JC_JCNI_ATTR;
	void	(*write$dcca4977396db63b)(_jc_env *, struct _jc_java_rmi_server_UID$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_server_UID$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_rmi_server_UID$vmethods	java_rmi_server_UID;
};

// Vtype
struct _jc_java_rmi_server_UID$vtype {
	_jc_type			type;
	_jc_java_rmi_server_UID$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_server_UID$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_rmi_server_UID$refs {
    _jc_java_rmi_server_UID$sub_refs	java_rmi_server_UID;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_server_UID$sub_nonrefs {
	jint	unique;
	jlong	time;
	jshort	count;
};

// Non-reference instance fields (object)
struct _jc_java_rmi_server_UID$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_rmi_server_UID$sub_nonrefs	java_rmi_server_UID;
};

// Object instance structure
struct _jc_java_rmi_server_UID$object {
	_jc_java_rmi_server_UID$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_server_UID$vtype	*vtype;
	_jc_java_rmi_server_UID$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_server_UID$vtype _jc_java_rmi_server_UID$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_server_UID, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_server_UID$class_object;

#endif	/* _JC_java_rmi_server_UID_H_ */
